"""
Django settings for eloquent project.

Generated by 'django-admin startproject' using Django 3.2.

For more information on this file, see
https://docs.djangoproject.com/en/3.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.2/ref/settings/
"""

import os

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
PROJECT_DIR = os.path.dirname(os.path.abspath(__file__))
BASE_DIR = os.path.dirname(PROJECT_DIR)

ALLOWED_HOSTS = ['*']

DEBUG = False
CSRF_USE_SESSIONS = True
SESSION_COOKIE_SECURE = True
SESSION_COOKIE_SAMESITE = 'Strict'
SESSION_EXPIRE_AT_BROWSER_CLOSE = True

# Media dir on production environment
MEDIA_URL = '/var/lib/eloquent/'
MEDIA_ROOT = os.path.join(MEDIA_URL, 'media')

# SECURITY WARNING: keep the secret key used in production secret!
if BASE_DIR.startswith('/usr/local/'):
    with open('/usr/local/etc/eloquent/secret.key') as fh:
        SECRET_KEY = fh.readline().strip()
elif BASE_DIR.startswith('/usr/'):
    with open('/etc/eloquent/secret.key') as fh:
        SECRET_KEY = fh.readline().strip()
else:
    # Settings for development environment:
    SECRET_KEY = 'django-insecure-9jg28*qgfn(_&clod&yxn!cy(k^tmw1@6c4%e-5*o6bn)=9kfw'
    DEBUG = True
    SESSION_COOKIE_SECURE = False
    MEDIA_ROOT = os.path.join(BASE_DIR, 'media')

if not DEBUG:
    # Settings for production environment (/var/log/syslog)
    LOGGING = {
        'version': 1,
        'disable_existing_loggers': False,
        'handlers': {
            'syslog': {
                'class': 'logging.handlers.SysLogHandler',
                'address': '/dev/log',
                'level': 'WARNING',
            },
        },
        'loggers': {
            # Redefine these because they're defined by the default
            # Django logging config:
            'django': {
                'handlers': ['syslog'],
                'level': 'WARNING',
                'propagate': True,
            },
            'django.server': {
                'handlers': ['syslog'],
                'level': 'WARNING',
                'propagate': True,
            },
            'eloquent': {
                'handlers': ['syslog'],
                'level': 'WARNING',
                'propagate': True,
            },
        },
        'root': {
            # Everything else goes here:
            'handlers': ['syslog'],
            'level': 'WARNING',
        },
    }
else:
    # Settings for local development (/var/log/apache2/error.log)
    LOGGING = {
        'version': 1,
        'disable_existing_loggers': False,
        'handlers': {
            'console': {
                'class': 'logging.StreamHandler',
            },
        },
        'loggers': {
            # Redefine these because they're defined by the default
            # Django logging config:
            'django': {
                'handlers': ['console'],
                'level': 'WARNING',
                'propagate': True,
            },
            'django.server': {
                'handlers': ['console'],
                'level': 'WARNING',
                'propagate': True,
            },
            'eloquent': {
                'handlers': ['console'],
                'level': 'DEBUG',
                'propagate': True,
            },
        },
        'root': {
            # Everything else goes here:
            'handlers': ['console'],
            'level': 'DEBUG',
        },

    }

# Application definition
INSTALLED_APPS = [
    # standard apps
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    # specific table forming apps
    'crispy_forms',
    'django_tables2',
    'django_filters',
    # our main app
    'elo'
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'eloquent.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(PROJECT_DIR, 'templates')],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'eloquent.wsgi.application'

# Database
# https://docs.djangoproject.com/en/3.2/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql',
        'NAME': 'eloquent',
        'USER': 'eloquent',
    },
}

# Password validation
# https://docs.djangoproject.com/en/3.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator', },
    {'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator', },
    {'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator', },
    {'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator', },
]

# Internationalization
# https://docs.djangoproject.com/en/3.2/topics/i18n/

LANGUAGE_CODE = 'en-us'
TIME_ZONE = 'UTC'
USE_I18N = True
USE_L10N = False
USE_TZ = False
DATE_FORMAT = "Y-m-D"
DATE_TIME_FORMAT = "Y-m-D H:M:S"

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.2/howto/static-files/
STATIC_URL = '/static/'
STATICFILES_DIRS = [
    os.path.join(PROJECT_DIR, 'static')
]
# STATIC_ROOT = 'static'

# Default primary key field type
# https://docs.djangoproject.com/en/3.2/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'
DJANGO_TABLES2_TEMPLATE = "django_tables2/bootstrap4.html"
CRISPY_TEMPLATE_PACK = 'bootstrap4'
